Class: Processor
- Inherits:
-
Object
- Object
- Processor
- Defined in:
- lib/confire/templates/processor.rb
Overview
This is where the main bits are processed
We can process lines and blocks here
Instance Method Summary collapse
-
#process_block(line_buffer, test_number) ⇒ Object
Will process a test case.
-
#process_line(line) ⇒ Object
Process the line to be stored in the line_buffer.
Instance Method Details
#process_block(line_buffer, test_number) ⇒ Object
Will process a test case. simply return whatever we want to print out as results
5 6 7 |
# File 'lib/confire/templates/processor.rb', line 5 def process_block(line_buffer, test_number) line_buffer end |
#process_line(line) ⇒ Object
Process the line to be stored in the line_buffer
10 11 12 |
# File 'lib/confire/templates/processor.rb', line 10 def process_line(line) line.split ' ' end |